
import React, { useEffect } from "react";
import { Helmet } from "react-helmet";
import Navbar from "@/components/Navbar";
import Footer from "@/components/Footer";
import { Button } from "@/components/ui/button";
import { Phone, Mail, MapPin, Clock, CheckCircle, ExternalLink } from "lucide-react";
import ContactForm from "@/components/ContactForm";

const ContactUs = () => {
  useEffect(() => {
    window.scrollTo(0, 0);
  }, []);

  return (
    <div className="flex flex-col min-h-screen">
      <Helmet>
        <title>Contact Us | FTFX Tech Solutions</title>
        <meta name="description" content="Get in touch with FTFX Tech Solutions for all your technology support needs. We provide expert IT support for both home and business customers." />
        <meta name="keywords" content="contact tech support, IT help, computer support, tech solutions contact, tech help contact" />
        <link rel="canonical" href="https://www.ftfxtechsolutions.com/contact-us" />
      </Helmet>

      <Navbar />

      <main className="flex-grow">
        {/* Hero Section */}
        <section className="bg-ftfx-dark-bg pt-28 pb-16 md:pt-32 md:pb-20 relative overflow-hidden">
          <div className="absolute top-0 left-1/2 -translate-x-1/2 w-full max-w-6xl h-[500px] bg-ftfx-purple/10 rounded-full blur-[120px] -z-10"></div>
          
          <div className="container mx-auto px-4 md:px-6">
            <div className="text-center">
              <h1 className="text-3xl md:text-4xl lg:text-5xl font-bold mb-6">
                Contact <span className="text-gradient">Us</span>
              </h1>
              <p className="text-lg text-gray-300 mb-8 max-w-2xl mx-auto">
                Get in touch with our team for support, inquiries, or to schedule a consultation.
              </p>
            </div>
          </div>
        </section>

        {/* Contact Form Section */}
        <section className="bg-ftfx-card-bg py-16 md:py-24">
          <div className="container mx-auto px-4 md:px-6">
            <div className="grid grid-cols-1 lg:grid-cols-2 gap-12">
              {/* Contact Information */}
              <div>
                <h2 className="text-3xl font-bold mb-6">Get in <span className="text-ftfx-purple">Touch</span></h2>
                <p className="text-gray-300 mb-8">
                  We're here to help with all your technology needs. Reach out to us using any of the contact methods 
                  below, or fill out the form and we'll get back to you as soon as possible.
                </p>
                
                <div className="space-y-6 mb-10">
                  <ContactItem 
                    icon={<Phone className="h-6 w-6" />}
                    title="Phone"
                    content="+1 (857) 855-5565"
                    link="tel:+18578555565"
                  />
                  <ContactItem 
                    icon={<Mail className="h-6 w-6" />}
                    title="Email"
                    content="support@ftfxtechsolutions.com"
                    link="mailto:support@ftfxtechsolutions.com"
                  />
                  <ContactItem 
                    icon={<MapPin className="h-6 w-6" />}
                    title="Address"
                    content="Casper, Wyoming"
                    link="https://maps.google.com/?q=Casper,Wyoming"
                  />
                  <ContactItem 
                    icon={<Clock className="h-6 w-6" />}
                    title="Business Hours"
                    content="Monday - Friday: 9am - 6pm EST"
                  />
                </div>
                
                <div className="bg-ftfx-accent-bg rounded-xl p-6 border border-ftfx-purple/20">
                  <h3 className="text-xl font-bold mb-3">Priority Support</h3>
                  <p className="text-gray-400 mb-4">
                    For clients with existing support plans, please mention your plan type in your message 
                    for expedited assistance.
                  </p>
                  <p className="flex items-center text-ftfx-purple">
                    <CheckCircle className="h-5 w-5 mr-2" />
                    <span className="font-medium">Faster response times for plan members</span>
                  </p>
                </div>
              </div>
              
              {/* Contact Form Component */}
              <ContactForm />
            </div>
          </div>
        </section>
        
        {/* FAQ Section */}
        <section className="bg-ftfx-dark-bg py-16 md:py-24">
          <div className="container mx-auto px-4 md:px-6">
            <div className="text-center mb-12">
              <h2 className="text-3xl font-bold mb-4">Frequently Asked <span className="text-ftfx-purple">Questions</span></h2>
              <p className="text-lg text-gray-400 max-w-2xl mx-auto">
                Find quick answers to common questions about our services.
              </p>
            </div>
            
            <div className="grid grid-cols-1 md:grid-cols-2 gap-8 max-w-4xl mx-auto">
              <FaqItem
                question="What are your typical response times?"
                answer="For clients with support plans, we typically respond within 1-4 hours during business hours. For general inquiries, we aim to respond within 24 business hours."
              />
              <FaqItem
                question="Do you offer same-day service?"
                answer="Yes, for urgent issues we provide same-day remote support for clients with our Priority and Business support plans. Availability for same-day service may vary."
              />
              <FaqItem
                question="Can you help with both Windows and Mac systems?"
                answer="Absolutely! Our technicians are certified in both Windows and Mac systems, as well as mobile devices and various software applications."
              />
              <FaqItem
                question="How do your support plans work?"
                answer="Our support plans provide different levels of service based on your needs, from basic troubleshooting to comprehensive IT management. Visit our Plans page for more details."
              />
              <FaqItem
                question="Do you offer on-site support?"
                answer="We primarily provide remote support, which allows for faster response times. For special cases requiring on-site assistance, we can arrange this for clients within certain geographic areas."
              />
              <FaqItem
                question="What if I need help outside business hours?"
                answer="Clients with our Business and Enterprise plans have access to after-hours emergency support for critical issues."
              />
            </div>
          </div>
        </section>

        {/* Map & Location Section */}
        <section className="bg-ftfx-card-bg py-16 md:py-24">
          <div className="container mx-auto px-4 md:px-6">
            <div className="grid grid-cols-1 lg:grid-cols-2 gap-12 items-center">
              <div>
                <h2 className="text-3xl font-bold mb-6">Our <span className="text-ftfx-purple">Location</span></h2>
                <p className="text-gray-300 mb-6">
                  While most of our support is provided remotely, our main office is located in Casper, Wyoming. 
                  We serve clients across the United States and beyond.
                </p>
                <div className="bg-ftfx-accent-bg rounded-xl p-6 border border-ftfx-purple/20">
                  <h3 className="text-xl font-bold mb-3">Remote Support</h3>
                  <p className="text-gray-400 mb-4">
                    Our secure remote support allows us to resolve most technical issues without requiring an on-site visit. 
                    This means faster resolution times and more convenience for you.
                  </p>
                  <p className="text-gray-400">
                    For situations that do require hands-on assistance, we can coordinate with local technicians in your area.
                  </p>
                  <div className="mt-6 p-4 bg-ftfx-dark-bg rounded-lg border border-ftfx-purple/10">
                    <h4 className="font-medium mb-2 text-white">Address</h4>
                    <p className="text-gray-300">
                      5830 E 2nd St, Ste 7000 #20837<br />
                      Casper, Wyoming 82609 US
                    </p>
                  </div>
                </div>
              </div>
              
              <div className="bg-ftfx-accent-bg p-3 rounded-xl shadow-xl border border-ftfx-purple/30 h-[400px] relative">
                {/* Static Map Image with Location Marker */}
                <div className="w-full h-full rounded-lg bg-gray-200 overflow-hidden relative">
                  <div className="absolute inset-0 bg-gradient-to-b from-ftfx-dark-bg/20 to-ftfx-dark-bg/5 z-10"></div>
                  
                  {/* Map Background Image */}
                  <div className="w-full h-full bg-[#f0f0f0] flex items-center justify-center relative">
                    <div className="text-center p-6 z-20">
                      <div className="bg-white/90 dark:bg-ftfx-dark-bg/90 rounded-xl p-5 shadow-lg border border-ftfx-purple/20">
                        <MapPin className="h-10 w-10 text-ftfx-purple mx-auto mb-3" />
                        <h3 className="font-bold text-lg mb-1">FTFX Tech Solutions</h3>
                        <p className="text-gray-600 dark:text-gray-300 mb-2 text-sm">
                          5830 E 2nd St, Ste 7000 #20837<br />
                          Casper, WY 82609
                        </p>
                        <Button 
                          className="mt-2 bg-ftfx-purple hover:bg-ftfx-dark-purple text-white w-full flex items-center justify-center"
                          asChild
                        >
                          <a 
                            href="https://maps.google.com/?q=5830+E+2nd+St,+Casper,+WY+82609"
                            target="_blank"
                            rel="noopener noreferrer"
                          >
                            <ExternalLink className="h-4 w-4 mr-2" />
                            Open in Google Maps
                          </a>
                        </Button>
                      </div>
                    </div>
                    
                    {/* Map Background Pattern */}
                    <div className="absolute inset-0 bg-[#f0f0f0] z-0">
                      <div className="w-full h-full grid grid-cols-10 grid-rows-10">
                        {Array.from({ length: 100 }).map((_, i) => (
                          <div key={i} className="border border-gray-200"></div>
                        ))}
                      </div>
                    </div>
                  </div>
                </div>
              </div>
            </div>
          </div>
        </section>

        {/* CTA Section */}
        <section className="bg-gradient-to-r from-ftfx-dark-purple to-ftfx-purple py-16 md:py-20">
          <div className="container mx-auto px-4 md:px-6 text-center">
            <h2 className="text-3xl md:text-4xl font-bold text-white mb-6">
              Need Immediate Assistance?
            </h2>
            <p className="text-lg text-white/80 mb-8 max-w-2xl mx-auto">
              Call us directly at +1 (857) 855-5565 for urgent support needs.
            </p>
            <div className="flex flex-wrap justify-center gap-4">
              <Button 
                className="bg-white text-ftfx-purple hover:bg-gray-100 px-8 py-6 text-lg font-medium"
                asChild
              >
                <a href="tel:+18578555565">
                  <Phone className="h-5 w-5 mr-2" />
                  Call Now
                </a>
              </Button>
            </div>
          </div>
        </section>
      </main>

      <Footer />
    </div>
  );
};

interface ContactItemProps {
  icon: React.ReactNode;
  title: string;
  content: string;
  link?: string;
}

const ContactItem = ({ icon, title, content, link }: ContactItemProps) => (
  <div className="flex items-start">
    <div className="bg-ftfx-purple/20 p-3 rounded-full mr-4">
      <div className="text-ftfx-purple">{icon}</div>
    </div>
    <div>
      <h3 className="font-semibold mb-1">{title}</h3>
      {link ? (
        <a 
          href={link} 
          className="text-ftfx-purple hover:text-ftfx-light-purple transition-colors"
          target={link.startsWith('http') ? "_blank" : undefined}
          rel={link.startsWith('http') ? "noopener noreferrer" : undefined}
        >
          {content}
        </a>
      ) : (
        <p className="text-gray-300">{content}</p>
      )}
    </div>
  </div>
);

interface FaqItemProps {
  question: string;
  answer: string;
}

const FaqItem = ({ question, answer }: FaqItemProps) => (
  <div className="bg-ftfx-accent-bg rounded-xl p-6 border border-ftfx-dark-purple/20 shadow-md">
    <h3 className="text-lg font-semibold mb-2">{question}</h3>
    <p className="text-gray-400">{answer}</p>
  </div>
);

export default ContactUs;
